@@ -66,7 +66,7 @@ class Orden(BaseModel):
         mensaje = etree.Element('mensaje', categoria=self.categoria)
         orden_pago = etree.SubElement(mensaje, 'ordenpago')
 
-        for element, value in self.dict(exclude_none=True, exclude={'categoria', 'op_ord_clave'}).items():  # noqa: WPS110, WPS221, E501
+        for element, value in self.json(exclude_none=True, exclude={'categoria', 'op_ord_clave'}).items():  # noqa: WPS110, WPS221, E501
             if element in self.__fields__:
                 if element == 'op_firma_dig':
                     subelement = etree.SubElement(orden_pago, 'opFirmaDig')
@@ -104,9 +104,12 @@ class Respuesta(BaseModel):
 
     id: str
     fecha_oper: int
-    err_codigo: int
+    err_codigo: types.CodigoError
     err_descripcion: str
 
+    class Config:  # noqa: WPS306, WPS431
+        use_enum_values = True
+
     def build_xml(self):
         mensaje = etree.Element('mensaje', categoria=self.categoria)
         orden_pago = etree.SubElement(mensaje, 'respuesta')
